/*****************************************************************************
 * Copyright (C) The Apache Software Foundation. All rights reserved.        *
 * ------------------------------------------------------------------------- *
 * This software is published under the terms of the Apache Software License *
 * version 1.1, a copy of which has been included  with this distribution in *
 * the LICENSE file.                                                         *
 *****************************************************************************/

package org.apache.slide.util.conf;

/**
 * Thrown when a <code>Configurable</code> component cannot be configured
 * properly, or if a value cannot be retrieved properly.
 *
 * @author <a href="mailto:scoobie@betaversion.org">Federico Barbieri</a>
 * @author <a href="mailto:stefano@apache.org">Stefano Mazzocchi</a>
 * @author <a href="mailto:fumagalli@exoffice.com">Pierpaolo Fumagalli</a>
 * @version CVS $Revision: 1.1 $ $Date: 2000/07/14 16:44:52 $
 */
public class ConfigurationException extends RuntimeException {

    /** The current configuration */
    private Configuration configuration=null;

    /**
     * Construct a new <code>ConfigurationException</code> instance.
     *
     * @param message The detail message for this exception (mandatory).
     * @param conf The configuration element.
     */
    public ConfigurationException(String message, Configuration conf) {
        super(message);
        this.configuration=conf;
    }

    /**
     * Get the <code>Configuration</code> element.
     *
     * @returns <code>Configuration</code> element associated, or
     *          <code>null</code> if there is none.
     */
    public Configuration getConfiguration() {
        return (this.configuration);
    }

    /**
     * Return this <code>ConfigurationException</code> (if possible with
     * location information).
     */
    public String getMessage() {
        String msg=super.getMessage();

        if (this.configuration!=null) {
            msg = msg + " @ " + this.configuration.getLocation();
        }

        return(msg);
    }
}
